@@ -1,8 +1,8 @@
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2020, Vanessa SOchat"
+__copyright__ = "Copyright 2020-2021, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
-__version__ = "0.0.12"
+__version__ = "0.0.13"
 AUTHOR = "Vanessa Sochat"
 AUTHOR_EMAIL = "vsochat@stanford.edu"
 NAME = "snakedeploy"
@@ -14,8 +14,11 @@ LICENSE = "LICENSE"
 ################################################################################
 # Global requirements
 
+INSTALL_REQUIRES = (
+    ("requests", {"min_version": None}),
+    ("pandas", {"min_version": None}),
+)
 
-INSTALL_REQUIRES = (("requests", {"min_version": None}),)
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 
 
